# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-12


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.HostInterface.hostInterface_create import HostInterfaceCreate
from WorkApi.API.HostInterface.hostInterface_massadd import HostInterfaceMassadd

from WorkData.Zabbix.interface import DataInterface

import allure

# allure.label("")


@allure.feature("测试模块：hostinterface.massadd")
class TestHostInterfaceMassadd(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机接口"
    base_ip = "10.0.0.28"
    base_hostids = [10266, 10286, 10507]
    base_dns = "sanshi.zmops.cn"
    base_port = "127"

    new_ip = "192.168.1.28"
    new_port = "721"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataInterface().delete_hostid(session=session, hostid=cls.base_hostids[0])

        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataInterface().delete_hostid(session=session, hostid=cls.base_hostids[1])

        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataInterface().delete_hostid(session=session, hostid=cls.base_hostids[2])

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：hostinterface.create")
    def hostinterface_create(self, dns=None, hostid=None, ip=None, main=None, port=None, _type=None, useip=None, bulk=None):
        api = HostInterfaceCreate(_host=self.host)
        api.dns = dns
        api.hostid = hostid
        api.ip = ip
        api.main = main
        api.port = port
        api.type = _type
        api.useip = useip
        api.bulk = bulk
        api.get_response()
        return api.response

    @allure.step("调用接口：hostinterface.massadd")
    def hostinterface_massadd(self, hosts=None, dns=None, ip=None, main=None, port=None, _type=None, useip=None, bulk=None):
        api = HostInterfaceMassadd(_host=self.host)
        api.hosts = hosts
        api.interfaces_dns = dns
        api.interfaces_ip = ip
        api.interfaces_main = main
        api.interfaces_port = port
        api.interfaces_type = _type
        api.interfaces_useip = useip
        api.interfaces_bulk = bulk
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("创建测试数据")
    def case_create(self, ip, hostid, main, port, _type, useip, bulk, dns):
        response = self.hostinterface_create(ip=ip, hostid=hostid, main=main, port=port, _type=_type, useip=useip, bulk=bulk, dns=dns)
        self.check_code(response=response, code=0)
        interfaceid = UtilsResponse().get_result(response=response)["interfaceids"][0]
        return interfaceid

    @allure.step("查询表：interface")
    def select_interface(self, interfaceid=None, hostid=None):
        session = self.db_session()
        sql = DataInterface().select_all_from_allKeys(session=session, interfaceid=interfaceid, hostid=hostid)
        return sql

    @allure.step("公共测试方法")
    def case_main(self, hosts, ips, dnss, mains, ports, _types, useips, bulks):
        response = self.hostinterface_massadd(hosts=hosts, ip=ips, dns=dnss, main=mains,
                                              port=ports, _type=_types, useip=useips, bulk=bulks)
        self.check_code(response=response, code=0)
        interfaceids = UtilsResponse().get_result(response=response)["interfaceids"]

        i = 0
        for q, w in enumerate(hosts):

            for x, y in enumerate(ips):

                self.check_select(interfaceid=interfaceids[i], hostid=hosts[q], ip=ips[x], dns=dnss[x], main=mains[x], port=ports[x],
                                  _type=_types[x], useip=useips[x], bulk=bulks[x])
                i = i + 1

    @allure.step("校验查询结果")
    def check_select(self, interfaceid, hostid, main, port, _type, useip, bulk, dns, ip):
        sql = self.select_interface(hostid=hostid, interfaceid=interfaceid)
        for x, y in enumerate(sql):
            assert y.main == main
            assert y.port == port
            assert y.type == _type
            assert y.useip == useip
            assert y.bulk == bulk
            if dns != "" and ip == "":
                assert y.dns == dns
            elif ip != "" and dns == "":
                assert y.ip == ip

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("hostinterface.massadd：一个主机批量创建多个主机接口")
    @allure.story("批量创建主机接口：一个主机批量创建多个主机接口")
    @allure.severity("blocker")
    def test_case_01(self):

        self.case_main(hosts=[self.base_hostids[0]], ips=[self.base_ip, self.base_ip], dnss=["", ""], mains=[1, 0], ports=["110", "111"], _types=[1, 1],
                       useips=[1, 1], bulks=[1, 1])

    @allure.title("hostinterface.massadd：多个主机批量创建多个主机接口")
    @allure.story("批量创建主机接口：多个主机批量创建多个主机接口")
    def test_case_02(self):
        self.case_main(hosts=[self.base_hostids[1], self.base_hostids[2]], ips=[self.base_ip, self.base_ip], dnss=["", ""], mains=[1, 0], ports=["110", "111"], _types=[1, 1],
                       useips=[1, 1], bulks=[1, 1])


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    # case_info = os.path.split(__file__)
    # case = UtilsCmd().pytest_cmd()
    # r = UtilsPyTest(case=case)
    # r.run_main()

    a = TestHostInterfaceMassadd()
    a.setup_class()
    a.test_case_02()
