# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-11


from __future__ import division

from WorkCase import CaseBase
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.TriggerPrototype.triggerPrototype_create import TriggerPrototypeCreate

from WorkData.Zabbix.triggers import DataTriggers
from WorkData.Zabbix.trigger_tag import DataTriggerTag
import allure

# allure.label("")


@allure.feature("测试模块：triggerprototype.create")
class TestTriggerPrototypeCreate(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机原型"
    base_description = "SS测试触发器原型"
    base_expression = "{Zabbix server:vfs.fs.size[{#FSNAME},pfree].last()}<20"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataTriggers().delete_description(session=session, description=cls.base_description)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：triggerprototype.create")
    def triggerprototype_create(self, description=None, expression=None, tags_tag=None, tags_value=None):
        api = TriggerPrototypeCreate(_host=self.host)
        api.description = description
        api.expression = expression
        api.tags_tag = tags_tag
        api.tags_value = tags_value
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("查询表：triggers")
    def select_triggers(self, triggerid=None):
        session = self.db_session()
        sql = DataTriggers().select_all_from_allKeys(session=session, triggerid=triggerid)
        return sql

    @allure.step("查询表：trigger_tag")
    def select_trigger_tag(self, triggerid=None):
        session = self.db_session()
        sql = DataTriggerTag().select_all_from_allKeys(session=session, triggerid=triggerid)
        return sql

    @allure.step("校验查询结果")
    def check_select(self, triggerid, description, tags_tag, tags_value):
        sql = self.select_triggers(triggerid=triggerid)
        for x, y in enumerate(sql):
            assert y.description == description
            assert y.status == 0
            assert y.value == 0

        sql = self.select_trigger_tag(triggerid=triggerid)
        assert sql != []
        for x, y in enumerate(sql):
            assert y.tag == tags_tag[x]
            assert y.value == tags_value[x]

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="groupid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回错误信息")
    def check_msg(self, response, msg):
        _msg = UtilsResponse().get_msg(response=response)
        assert _msg == msg

    @allure.step("断言返回错误结果")
    def check_status(self, response, status):
        _status = UtilsResponse().get_status(response=response)
        assert _status == status

    @allure.title("triggerprototype.create：创建一个触发器")
    @allure.story("创建触发器原型：创建一个触发器")
    @allure.severity("blocker")
    def test_case_01(self):
        tags_tag = ["volume"]
        tags_value = ["{#FSNAME}"]
        response = self.triggerprototype_create(description=self.base_description, expression=self.base_expression, tags_tag=tags_tag, tags_value=tags_value)
        self.check_code(response=response, code=0)

        triggerid = UtilsResponse().get_result(response=response)["triggerids"][0]
        self.check_select(triggerid=triggerid, description=self.base_description, tags_tag=tags_tag, tags_value=tags_value)


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()

    # a = TestTriggerPrototypeCreate()
    # a.setup_class()
    # a.test_case_01()
    # a.test_case_02()
    # a.test_case_03()
    # a.test_case_06()
