# -*- coding: utf-8 -*-
# 测试用例
# 作者: 陈磊
# 时间: 2019-11-14


from __future__ import division
from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase
from WorkUtils.UtilsResponse import UtilsResponse
from WorkApi.API.TriggerPrototype.triggerPrototype_create import TriggerPrototypeCreate
from WorkApi.API.TriggerPrototype.triggerPrototype_get import TriggerPrototypeGet

from WorkData.Zabbix.triggers import DataTriggers

from WorkCase import CaseBase

import allure


# allure.label("")


@allure.feature("测试模块：triggerprototype.get")
class TestTriggerPrototypeGet(object):
    log = UtilsLog()
    env = CaseBase().environment
    host = env["host"]
    db_url = env["db_url"]
    db_port = env["db_port"]
    db_user = env["db_user"]
    db_pw = env["db_pw"]
    db_base = env["db_base"]
    base_name = "SS测试主机原型"
    base_description = "SS测试触发器原型"
    base_expression = "{Zabbix server:vfs.fs.size[{#FSNAME},pfree].last()}<20"

    @classmethod
    def setup_class(cls):
        cls.log.debug("开始执行测试套件.......")
        session = UtilsDataBase().conn_mysql(db_url=cls.db_url, db_port=cls.db_port, db_base=cls.db_base, db_user=cls.db_user, db_pw=cls.db_pw)
        DataTriggers().delete_description(session=session, description=cls.base_description)

    @classmethod
    def teardown_class(cls):
        cls.log.debug("结束执行测试套件.......")

    def setup_method(self):
        self.log.debug("测试用例执行开始...")

    def teardown_method(self):
        self.log.debug("测试用例执行结束...")

    @allure.step("调用接口：triggerprototype.create")
    def triggerprototype_create(self, description=None, expression=None, tags_tag=None, tags_value=None):
        api = TriggerPrototypeCreate(_host=self.host)
        api.description = description
        api.expression = expression
        api.tags_tag = tags_tag
        api.tags_value = tags_value
        api.get_response()
        return api.response

    @allure.step("创建测试数据")
    def case_create(self):
        tags_tag = ["volume"]
        tags_value = ["{#FSNAME}"]
        response = self.triggerprototype_create(description=self.base_description, expression=self.base_expression, tags_tag=tags_tag, tags_value=tags_value)
        self.check_code(response=response, code=0)
        triggerid = UtilsResponse().get_result(response=response)["triggerids"][0]
        return triggerid

    @allure.step("调用接口：triggerprototype.get")
    def triggerprototype_get(self, active=None, applicationids=None, discoveryids=None, functions=None, group=None,
                             groupids=None, host=None, hostids=None, inherited=None, maintenance=None, min_severity=None,
                             monitored=None, templated=None, templateids=None, triggerids=None, expandExpression=None,
                             selectDiscoveryRule=None, selectFunctions=None, selectGroups=None, selectHosts=None,
                             selectItems=None, selectDependencies=None, selectTags=None,
                             countOutput=None, editable=None, excludeSearch=None,
                             _filter=None, limit=None, output=None, preservekeys=None, search=None, searchByAny=None,
                             searchWildcardsEnabled=None, sortfield=None, sortorder=None, startSearch=None):
        api = TriggerPrototypeGet(_host=self.host)
        api.active = active
        api.applicationids = applicationids
        api.discoveryids = discoveryids
        api.functions = functions
        api.group = group
        api.groupids = groupids
        api.host = host
        api.hostids = hostids
        api.inherited = inherited
        api.maintenance = maintenance
        api.min_severity = min_severity
        api.monitored = monitored
        api.templated = templated
        api.templateids = templateids
        api.triggerids = triggerids
        api.expandExpression = expandExpression
        api.selectDiscoveryRule = selectDiscoveryRule
        api.selectFunctions = selectFunctions
        api.selectGroups = selectGroups
        api.selectHosts = selectHosts
        api.selectItems = selectItems
        api.selectDependencies = selectDependencies
        api.selectTags = selectTags
        api.countOutput = countOutput
        api.editable = editable
        api.excludeSearch = excludeSearch
        api.filter = _filter
        api.limit = limit
        api.output = output
        api.preservekeys = preservekeys
        api.search = search
        api.searchByAny = searchByAny
        api.searchWildcardsEnabled = searchWildcardsEnabled
        api.sortfield = sortfield
        api.sortorder = sortorder
        api.startSearch = startSearch
        api.get_response()
        return api.response

    @allure.step("连接数据库：zabbix")
    def db_session(self):
        session = UtilsDataBase().conn_mysql(db_url=self.db_url, db_port=self.db_port, db_base=self.db_base, db_user=self.db_user, db_pw=self.db_pw)
        return session

    @allure.step("查询表：triggers")
    def select_hosts(self, triggerid=None):
        session = self.db_session()
        sql = DataTriggers().select_all_from_allKeys(session=session, triggerid=triggerid)
        return sql

    @allure.step("断言返回结果：校验排序")
    def check_sortfield(self, response, possible):
        result = UtilsResponse().get_result(response=response)
        UtilsResponse().check_sort(_list=result, key="triggerid", possible=possible)

    @allure.step("断言返回结果：校验返回数据的数量")
    def check_num(self, response, num):
        result = UtilsResponse().get_result(response=response)
        assert len(result) == num

    @allure.step("断言返回结果")
    def check_code(self, response, code):
        _code = UtilsResponse().get_code(response=response)
        assert _code == code

    @allure.step("断言返回结果：与数据库结果是否一致")
    def check_sql(self, response, triggerid):
        sql = self.select_hosts(triggerid=triggerid)
        result = UtilsResponse().get_result(response=response)
        for x, y in enumerate(sql):
            assert y.description in UtilsResponse().get_values_from_key(_dict=result, key="description")
            assert y.status in UtilsResponse().get_values_from_key(_dict=result, key="status")
            assert y.value in UtilsResponse().get_values_from_key(_dict=result, key="value")
            assert y.flags in UtilsResponse().get_values_from_key(_dict=result, key="flags")
        for x, y in enumerate(result):
            assert y["description"] in UtilsResponse().get_values_from_sql(_sql=sql, key="description")
            assert y["status"] in UtilsResponse().get_values_from_sql(_sql=sql, key="status")
            assert y["value"] in UtilsResponse().get_values_from_sql(_sql=sql, key="value")
            assert y["flags"] in UtilsResponse().get_values_from_sql(_sql=sql, key="flags")

    @allure.title("triggerprototype.get：无参数调用")
    @allure.story("查询触发器原型：无参数调用")
    @allure.severity("blocker")
    def test_case_01(self):
        response = self.triggerprototype_get()
        self.check_code(response=response, code=0)

    @allure.title("triggerprototype.get：countOutput=true")
    @allure.story("查询触发器原型：countOutput=true")
    def test_case_02(self):
        response = self.triggerprototype_get(countOutput="true")
        self.check_code(response=response, code=0)

    @allure.title("triggerprototype.get：output=[description]")
    @allure.story("查询触发器原型：output=[description]")
    def test_case_03(self):
        response = self.triggerprototype_get(output=["description"])
        self.check_code(response=response, code=0)

    @allure.title("triggerprototype.get：triggerids=特定IDs, output=[description]")
    @allure.story("查询触发器原型：triggerids=特定IDs, output=[description]")
    def test_case_04(self):
        triggerid = self.case_create()

        response = self.triggerprototype_get(triggerids=[triggerid], output=["description"])
        self.check_code(response=response, code=0)

    @allure.title("triggerprototype.get：triggerids=特定IDs, output=[description, status, value, flags]")
    @allure.story("查询触发器原型：triggerids=特定IDs, output=[description, status, value, flags]")
    def test_case_05(self):
        triggerid = self.case_create()

        response = self.triggerprototype_get(triggerids=[triggerid], output=["description", "status", "value", "flags"])
        self.check_code(response=response, code=0)
        self.check_sql(response=response, triggerid=triggerid)

    @allure.title("triggerprototype.get：limit=1")
    @allure.story("查询触发器原型：limit=1")
    def test_case_06(self):
        self.case_create()

        response = self.triggerprototype_get(limit=1)
        self.check_code(response=response, code=0)
        result = UtilsResponse().get_result(response=response)
        assert len(result) == 1

    @allure.title("triggerprototype.get：sortfield=hostid")
    @allure.story("查询触发器原型：sortfield=hostid")
    def test_case_07(self):
        response = self.triggerprototype_get(sortfield=["triggerid"])
        self.check_code(response=response, code=0)
        self.check_sortfield(response=response, possible=True)

    @allure.title("triggerprototype.get：sortfield=triggerid, sortorder=ASC")
    @allure.story("查询触发器原型：sortfield=triggerid, sortorder=ASC")
    def test_case_8(self):
        response = self.triggerprototype_get(sortfield=["triggerid"], sortorder=["ASC"])
        self.check_code(response=response, code=0)
        self.check_sortfield(response=response, possible="ASC")

    @allure.title("triggerprototype.get：sortfield=triggerid, sortorder=DESC")
    @allure.story("查询触发器原型：sortfield=triggerid, sortorder=DESC")
    def test_case_9(self):
        response = self.triggerprototype_get(sortfield=["triggerid"], sortorder=["DESC"])
        self.check_code(response=response, code=0)
        self.check_sortfield(response=response, possible="DESC")


if __name__ == "__main__":
    from WorkUtils.UtilsPyTest import UtilsPyTest
    from WorkUtils.UtilsCmd import UtilsCmd

    import os

    # 执行自动化测试用例
    case_info = os.path.split(__file__)
    case = UtilsCmd().pytest_cmd()
    r = UtilsPyTest(case=case, case_info=case_info)
    r.run_main()
    # a = TestTriggerPrototypeGet()
    # a.setup_class()
    # a.test_case_04()
