# -*- coding: utf_8 -*-
# 表名: problem
# 作者: 陈磊
# 时间: 2019-11-14


from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import Column, Integer, VARCHAR, BIGINT, SMALLINT, DATETIME, DECIMAL, BigInteger, FLOAT, NUMERIC, TEXT
from sqlalchemy.orm.exc import MultipleResultsFound, NoResultFound
from sqlalchemy import or_

from WorkUtils.UtilsLog import UtilsLog
from WorkUtils.UtilsDataBase import UtilsDataBase

import time

Base = declarative_base()


class Problem(Base):
    """
    告警信息表
    """
    __tablename__ = "problem"

    eventid = Column(BigInteger, primary_key=True)
    source = Column(Integer)
    object = Column(Integer)
    objectid = Column(BigInteger)
    clock = Column(Integer)
    ns = Column(Integer)
    r_eventid = Column(BigInteger)
    r_clock = Column(Integer)
    r_ns = Column(Integer)
    correlationid = Column(BigInteger)
    userid = Column(BigInteger)
    name = Column(VARCHAR(2048))
    acknowledged = Column(Integer)
    severity = Column(Integer)


class DataProblem(object):
    def __init__(self):
        self.log = UtilsLog()
        self.log.info(self.__class__)

        self.table = Problem

    def select_all_from_allKeys(self, session, eventid=None, source=None, severity=None):
        """
        :param session: 指针
        :param eventid:
        :param source:
        :param severity:
        :return: 查询结果
        """
        self.log.debug("查询数据库:")
        try:
            base = UtilsDataBase()
            base.add_param(_key="eventid", value=eventid)
            base.add_param(_key="source", value=source)
            base.add_param(_key="severity", value=severity)
            sql_rep = session.query(self.table).filter_by(**base.param).all()
            self.log.debug(sql_rep)
            session.close()
            return sql_rep
        except UtilsDataBase().errors as error:
            self.log.error("异常:")
            self.log.error(error)
            session.close()
            return error

    def delete_like_name(self, session, name):
        """
        :param session: 指针
        :param name:
        :return:
        """
        self.log.debug("查询数据库:")
        try:
            self.log.debug("删除相关测试数据")
            session.query(self.table).filter(self.table.name.like(str(name) + "%")).delete(synchronize_session=False)
            # session.delete(sql)
            session.commit()
            session.close()
            self.log.debug("删除成功")
            return True
        except UtilsDataBase().errors as error:
            self.log.error("异常:")
            self.log.error(error)
            session.close()
            return error
